==> blesta-5.10.2.zip: blesta/language/tr_tr/client_quotations.php <==
<?php
/**
 * Client Quotations
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['ClientQuotations.invoices.no_results'] = 'Bu teklifle ilişkili herhangi bir fatura bulunmamaktadır.';
$lang['ClientQuotations.invoices.heading_date_billed'] = 'Fatura Tarihi';
$lang['ClientQuotations.invoices.heading_paid'] = 'Ücretli';
$lang['ClientQuotations.invoices.heading_amount'] = 'Miktar';
$lang['ClientQuotations.invoices.heading_invoice'] = 'Fatura #';
$lang['ClientQuotations.approve.field_submit'] = 'Onaylamak';
$lang['ClientQuotations.approve.field_cancel'] = 'İptal et, onaylama';
$lang['ClientQuotations.approve.field_password'] = 'Onaylamak için Giriş Şifresi';
$lang['ClientQuotations.approve.heading_approve'] = 'Onaylamak';
$lang['ClientQuotations.index.no_results'] = '1$s Teklifiniz yok.';
$lang['ClientQuotations.index.option_approve'] = 'Onaylamak';
$lang['ClientQuotations.index.option_view'] = 'Görünüm';
$lang['ClientQuotations.index.heading_options'] = 'Seçenekler';
$lang['ClientQuotations.index.heading_date_expires'] = 'Tarih Sonu';
$lang['ClientQuotations.index.heading_date_created'] = 'Tarih Oluşturuldu';
$lang['ClientQuotations.index.heading_total'] = 'Miktar';
$lang['ClientQuotations.index.heading_subtotal'] = 'Ara Toplam';
$lang['ClientQuotations.index.heading_title'] = 'Başlık';
$lang['ClientQuotations.index.heading_quotation'] = 'Alıntı #';
$lang['ClientQuotations.index.boxtitle_quotations'] = 'Alıntılar';
$lang['ClientQuotations.index.category_expired'] = 'Süresi doldu';
$lang['ClientQuotations.index.category_approved'] = 'Onaylandı';
$lang['ClientQuotations.index.category_pending'] = 'Beklemede';
$lang['ClientQuotations.index.page_title'] = 'Müşteri #%1$s Teklifler';
$lang['ClientQuotations.!success.approved_quotation'] = 'Teklif başarıyla onaylanmıştır.';
$lang['ClientQuotations.!error.password_mismatch'] = 'Parola, oturum açma parolanızla eşleşmiyor.';

==> blesta-5.11.4.zip: blesta/language/tr_tr/client_quotations.php <==
<?php
/**
 * Client Quotations
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['ClientQuotations.invoices.no_results'] = 'Bu teklifle ilişkili herhangi bir fatura bulunmamaktadır.';
$lang['ClientQuotations.invoices.heading_date_billed'] = 'Fatura Tarihi';
$lang['ClientQuotations.invoices.heading_paid'] = 'Ücretli';
$lang['ClientQuotations.invoices.heading_amount'] = 'Miktar';
$lang['ClientQuotations.invoices.heading_invoice'] = 'Fatura #';
$lang['ClientQuotations.approve.field_submit'] = 'Onaylamak';
$lang['ClientQuotations.approve.field_cancel'] = 'İptal et, onaylama';
$lang['ClientQuotations.approve.field_password'] = 'Onaylamak için Giriş Şifresi';
$lang['ClientQuotations.approve.heading_approve'] = 'Onaylamak';
$lang['ClientQuotations.index.option_approve'] = 'Onaylamak';
$lang['ClientQuotations.index.option_view'] = 'Görünüm';
$lang['ClientQuotations.index.heading_options'] = 'Seçenekler';
$lang['ClientQuotations.index.heading_date_expires'] = 'Tarih Sonu';
$lang['ClientQuotations.index.heading_date_created'] = 'Tarih Oluşturuldu';
$lang['ClientQuotations.index.heading_total'] = 'Miktar';
$lang['ClientQuotations.index.heading_subtotal'] = 'Ara Toplam';
$lang['ClientQuotations.index.heading_title'] = 'Başlık';
$lang['ClientQuotations.index.heading_quotation'] = 'Alıntı #';
$lang['ClientQuotations.index.boxtitle_quotations'] = 'Alıntılar';
$lang['ClientQuotations.index.category_expired'] = 'Süresi doldu';
$lang['ClientQuotations.index.category_approved'] = 'Onaylandı';
$lang['ClientQuotations.index.category_pending'] = 'Beklemede';
$lang['ClientQuotations.index.page_title'] = 'Müşteri #%1$s Teklifler';
$lang['ClientQuotations.!success.approved_quotation'] = 'Teklif başarıyla onaylanmıştır.';
$lang['ClientQuotations.!error.password_mismatch'] = 'Parola, oturum açma parolanızla eşleşmiyor.';
$lang['ClientQuotations.index.no_results'] = 'Hiç %1$s yok Alıntılar.';
